{ config, pkgs, ... }:

{
  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  home.username = "sid";
  home.homeDirectory = "/home/sid";

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  home.stateVersion = "25.05"; # Please read the comment before changing.

  # The home.packages option allows you to install Nix packages into your
  # environment.
  home.packages = with pkgs; [
    gnupg
    pinentry-curses
    hyprpaper
  ];

  # Home Manager is pretty good at managing dotfiles. The primary way to manage
  # plain files is through 'home.file'.
  home.file = {
  };

  # Home Manager can also manage your environment variables through
  # 'home.sessionVariables'. These will be explicitly sourced when using a
  # shell provided by Home Manager. If you don't want to manage your shell
  # through Home Manager then you have to manually source 'hm-session-vars.sh'
  # located at either
  home.sessionVariables = {
    # EDITOR = "emacs";
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

	programs = {
		# Nixhelper
		nh = {
			enable = true;
			clean.enable = true;
			clean.extraArgs = "--keep-since 4d --keep 3";
			flake = "../../flake.nix";
		};

		# Vim config
		vim = {
			enable = true;
			settings = {
				tabstop = 2;
				shiftwidth = 2;
			};
    };

    # Enable fish
    fish = {
      enable = true;
      interactiveShellInit = ''
        fastfetch
      '';
    };

    # Hyprland stuff
    wofi.enable = true;
    waybar.enable = true;
  };

  services = {
    # GPG setup
    gpg-agent = {
      enable = true;
      pinentry.package = pkgs.pinentry-curses;
    };

    # Hyprland stuff
    hyprpaper = {
      enable = true;
      settings = {
        preload = [ "~/nixos/.github/assets/evangelion_unit-01.png" ];
        wallpaper = [ ",~/nixos/.github/assets/evangelion_unit-01.png" ];
      };
    };
  };

}
